@@ -2,7 +2,7 @@ package Lingua::EN::Inflexion;
 use 5.010; use warnings;
 use Carp;
 
-our $VERSION = '0.000004';
+our $VERSION = '0.000005';
 
 # Import noun, verb, and adj classes...
 use Lingua::EN::Inflexion::Term;
@@ -69,7 +69,7 @@ sub inflect($) {
 
     my $inflexion = 'singular';
 
-    state $transform = {
+    my $transform = {
         'N'  => sub{
                     my ($term, $opts) = @_;
                     carp "Unknown '$_' option to <N:...> command"
@@ -170,7 +170,7 @@ Lingua::EN::Inflexion - Inflect English nouns, verbs, adjectives, and articles
 
 =head1 VERSION
 
-This document describes Lingua::EN::Inflexion version 0.000004
+This document describes Lingua::EN::Inflexion version 0.000005
 
 
 =head1 SYNOPSIS
@@ -1128,7 +1128,7 @@ but not for:
 
 =head3 Conflicting inflexions
 
-English noun inflexions are (unfortunately) not always one-to-to.
+English noun inflexions are (unfortunately) not always one-to-one.
 
 If two or more inflexions specify the same plural form, the module
 always defaults to the first one to appear in the file. Hence, given:
